@@ -309,13 +309,17 @@ soup_auth_ntlm_update_connection (SoupConnectionAuth *auth, SoupMessage *msg,
 			return TRUE;
 		}
 
+#ifdef USE_NTLM_AUTH
 		if (priv->sso_available) {
 			conn->state = SOUP_NTLM_SSO_FAILED;
 			priv->password_state = SOUP_NTLM_PASSWORD_NONE;
 		} else {
+#endif
 			conn->state = SOUP_NTLM_FAILED;
 			priv->password_state = SOUP_NTLM_PASSWORD_REJECTED;
+#ifdef USE_NTLM_AUTH
 		}
+#endif
 		return TRUE;
 	}
 
@@ -831,7 +835,8 @@ md4sum (const unsigned char *in, int nbytes, unsigned char digest[16])
 	guint32 A, B, C, D, AA, BB, CC, DD, X[16];
 	int pbytes, nbits = nbytes * 8, i, j;
 
-	pbytes = (120 - (nbytes % 64)) % 64;
+	/* There is *always* padding of at least one bit. */
+	pbytes = ((119 - (nbytes % 64)) % 64) + 1;
 	M = alloca (nbytes + pbytes + 8);
 	memcpy (M, in, nbytes);
 	memset (M + nbytes, 0, pbytes + 8);
