@@ -117,7 +117,7 @@ test_sum (void)
 
 	SOUP_TEST_SKIP_IF_NO_XMLRPC_SERVER;
 
-	debug_printf (1, "sum (array of int -> int): ");
+	debug_printf (2, "sum (array of int -> int): ");
 
 	ints = g_value_array_new (10);
 	for (i = sum = 0; i < 10; i++) {
@@ -153,7 +153,7 @@ test_countBools (void)
 
 	SOUP_TEST_SKIP_IF_NO_XMLRPC_SERVER;
 
-	debug_printf (1, "countBools (array of boolean -> struct of ints): ");
+	debug_printf (2, "countBools (array of boolean -> struct of ints): ");
 
 	bools = g_value_array_new (10);
 	for (i = trues = falses = 0; i < 10; i++) {
@@ -198,7 +198,7 @@ test_md5sum (void)
 
 	SOUP_TEST_SKIP_IF_NO_XMLRPC_SERVER;
 
-	debug_printf (1, "md5sum (base64 -> base64)\n");
+	debug_printf (2, "md5sum (base64 -> base64)\n");
 
 	data = g_byte_array_new ();
 	g_byte_array_set_size (data, 256);
@@ -234,7 +234,7 @@ test_dateChange (void)
 
 	SOUP_TEST_SKIP_IF_NO_XMLRPC_SERVER;
 
-	debug_printf (1, "dateChange (date, struct of ints -> time)\n");
+	debug_printf (2, "dateChange (date, struct of ints -> time)\n");
 
 	date = soup_date_new (1970 + (g_random_int_range (0, 50)),
 			      1 + g_random_int_range (0, 12),
@@ -343,7 +343,7 @@ test_echo (void)
 
 	SOUP_TEST_SKIP_IF_NO_XMLRPC_SERVER;
 
-	debug_printf (1, "echo (array of string -> array of string):\n");
+	debug_printf (2, "echo (array of string -> array of string):\n");
 
 	originals = g_value_array_new (N_ECHO_STRINGS);
 	for (i = 0; i < N_ECHO_STRINGS; i++) {
@@ -373,10 +373,7 @@ test_echo (void)
 
 	for (i = 0; i < echoes->n_values; i++) {
 		if (!server_test && strcmp (echo_strings_broken[i], g_value_get_string (&echoes->values[i])) == 0) {
-			/* We want to call g_test_skip(), but as of glib 2.38
-			 * that marks the test as failed rather than succeeded.
-			 */
-			// FIXME g_test_skip ("PHP bug");
+			g_test_skip ("PHP bug");
 			g_value_array_free (echoes);
 			return;
 		}
@@ -396,9 +393,11 @@ test_ping (gconstpointer include_params)
 	char *out;
 	gboolean ret;
 
+	g_test_bug ("671661");
+
 	SOUP_TEST_SKIP_IF_NO_XMLRPC_SERVER;
 
-	debug_printf (1, "ping (void (%s) -> string)\n",
+	debug_printf (2, "ping (void (%s) -> string)\n",
 		      include_params ? "empty <params>" : "no <params>");
 
 	params = soup_value_array_new ();
@@ -467,8 +466,6 @@ test_fault_malformed (void)
 {
 	SOUP_TEST_SKIP_IF_NO_XMLRPC_SERVER;
 
-	debug_printf (1, "malformed request: ");
-
 	do_bad_xmlrpc ("<methodCall/>");
 }
 
@@ -477,8 +474,6 @@ test_fault_method (void)
 {
 	SOUP_TEST_SKIP_IF_NO_XMLRPC_SERVER;
 
-	debug_printf (1, "request to non-existent method: ");
-
 	do_bad_xmlrpc ("<methodCall><methodName>no_such_method</methodName><params><param><value><int>1</int></value></param></params></methodCall>");
 }
 
@@ -487,8 +482,6 @@ test_fault_args (void)
 {
 	SOUP_TEST_SKIP_IF_NO_XMLRPC_SERVER;
 
-	debug_printf (1, "request with invalid args: ");
-
 	do_bad_xmlrpc ("<methodCall><methodName>sum</methodName><params><param><value><int>1</int></value></param></params></methodCall>");
 }
 
@@ -507,7 +500,7 @@ main (int argc, char **argv)
 
 	test_init (argc, argv, xmlrpc_entries);
 
-	if (!uri) {
+	if (!uri && !server_test) {
 		apache_init ();
 		uri = default_uri;
 	}
